==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/OPTIONREVIEWSTATUS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour OPTIONREVIEWSTATUS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="OPTIONREVIEWSTATUS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OPTIONSREVIEWED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONVERSIONOPTIONSTEPID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OPTIONREVIEWSTATUS_Type", propOrder = {
    "optionsreviewed",
    "conversionoptionstepid"
})
public class OPTIONREVIEWSTATUS_Type {

    @XmlElement(name = "OPTIONSREVIEWED")
    protected String optionsreviewed;
    @XmlElement(name = "CONVERSIONOPTIONSTEPID")
    @XmlSchemaType(name = "long")
    protected Integer conversionoptionstepid;

    /**
     * Obtient la valeur de la propriété optionsreviewed.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOPTIONSREVIEWED() {
        return optionsreviewed;
    }

    /**
     * Définit la valeur de la propriété optionsreviewed.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOPTIONSREVIEWED(String value) {
        this.optionsreviewed = value;
    }

    /**
     * Obtient la valeur de la propriété conversionoptionstepid.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getCONVERSIONOPTIONSTEPID() {
        return conversionoptionstepid;
    }

    /**
     * Définit la valeur de la propriété conversionoptionstepid.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setCONVERSIONOPTIONSTEPID(Integer value) {
        this.conversionoptionstepid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/OPTIONREVIEWSTATUS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for OPTIONREVIEWSTATUS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OPTIONREVIEWSTATUS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OPTIONSREVIEWED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONVERSIONOPTIONSTEPID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OPTIONREVIEWSTATUS_Type", propOrder = {
    "optionsreviewed",
    "conversionoptionstepid"
})
public class OPTIONREVIEWSTATUS_Type {

    @XmlElement(name = "OPTIONSREVIEWED")
    protected String optionsreviewed;
    @XmlElement(name = "CONVERSIONOPTIONSTEPID")
    @XmlSchemaType(name = "long")
    protected Integer conversionoptionstepid;

    /**
     * Gets the value of the optionsreviewed property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOPTIONSREVIEWED() {
        return optionsreviewed;
    }

    /**
     * Sets the value of the optionsreviewed property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOPTIONSREVIEWED(String value) {
        this.optionsreviewed = value;
    }

    /**
     * Gets the value of the conversionoptionstepid property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getCONVERSIONOPTIONSTEPID() {
        return conversionoptionstepid;
    }

    /**
     * Sets the value of the conversionoptionstepid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setCONVERSIONOPTIONSTEPID(Integer value) {
        this.conversionoptionstepid = value;
    }

}
